From 3aa091a9fdabebf982eb219c3a3dae3424ab6ef4 Mon Sep 17 00:00:00 2001
From: Ilya Shpigor <shpigor@etersoft.ru>
Date: Thu, 9 Apr 2009 15:46:57 +0400
Subject: [PATCH 1/3] user32/winex11.drv: Using the Drop/Raise window functions for all aplications (eterbug #3768)

---
 dlls/user32/win.c         |   10 ++++++----
 dlls/winex11.drv/event.c  |   10 ++++------
 dlls/winex11.drv/window.c |    9 +--------
 3 files changed, 11 insertions(+), 18 deletions(-)

diff --git a/dlls/user32/win.c b/dlls/user32/win.c
index d016ff7..d7aab44 100644
--- a/dlls/user32/win.c
+++ b/dlls/user32/win.c
@@ -38,8 +38,6 @@
 #include "winerror.h"
 #include "wine/debug.h"
 
-#include "wine/etersoft.h"
-
 WINE_DEFAULT_DEBUG_CHANNEL(win);
 
 #define NB_USER_HANDLES  ((LAST_USER_HANDLE - FIRST_USER_HANDLE + 1) >> 1)
@@ -2112,8 +2110,12 @@ LONG_PTR WIN_SetWindowLong( HWND hwnd, INT offset, UINT size, LONG_PTR newval, B
         case GWL_EXSTYLE:
             req->flags = SET_WIN_EXSTYLE;
             /* WS_EX_TOPMOST can only be changed through SetWindowPos */
-            LOADETER_FUNC(etersoft_1version);
-            if (!(etersoft_1version && (etersoft_1version() == 8)))
+
+            /* Eterbug #3768, #3024
+             * We need able to set WS_EX_TOPMOST style without
+             * SetWindowPos calling for Drop/Raise windows
+             */
+            if (0)
                 newval = (newval & ~WS_EX_TOPMOST) | (wndPtr->dwExStyle & WS_EX_TOPMOST);
             req->ex_style = newval;
             break;
diff --git a/dlls/winex11.drv/event.c b/dlls/winex11.drv/event.c
index 86d8058..b79a294 100644
--- a/dlls/winex11.drv/event.c
+++ b/dlls/winex11.drv/event.c
@@ -701,13 +701,11 @@ static void X11DRV_FocusOut( HWND hwnd, XEvent *xev )
     {
         if (hwnd != GetForegroundWindow()) return;
     }
-    else if (etersoft_1version)
+
+    if (data->managed && data->whole_window)
     {
-        if (data->managed && data->whole_window)
-        {
-            SetWindowLongW(hwnd, GWL_EXSTYLE, GetWindowLongW( hwnd, GWL_EXSTYLE ) & ~WS_EX_TOPMOST);
-            update_net_wm_states( event->display, data );
-        }
+        SetWindowLongW(hwnd, GWL_EXSTYLE, GetWindowLongW( hwnd, GWL_EXSTYLE ) & ~WS_EX_TOPMOST);
+        update_net_wm_states( event->display, data );
     }
 
     SendMessageW( hwnd, WM_CANCELMODE, 0, 0 );
diff --git a/dlls/winex11.drv/window.c b/dlls/winex11.drv/window.c
index e93d3db..2aa1070 100644
--- a/dlls/winex11.drv/window.c
+++ b/dlls/winex11.drv/window.c
@@ -2216,8 +2216,6 @@ void CDECL X11DRV_DropWindow( HWND hwnd )
     Display *display = thread_display();
     struct x11drv_win_data *data;
 
-    LOADETER_FUNC(etersoft_1version);
-    if ( etersoft_1version && (etersoft_1version() != 8) ) return;
     if (GetWindowLongW(hwnd, GWL_STYLE) & WS_MINIMIZE) return;
     if (!(hwnd = GetAncestor( hwnd, GA_ROOT ))) return;
     if (!(data = X11DRV_get_win_data( hwnd ))) return;
@@ -2260,16 +2258,11 @@ void CDECL X11DRV_SetFocus( HWND hwnd )
     Display *display = thread_display();
     struct x11drv_win_data *data;
     XWindowChanges changes;
-    BOOL b1c8 = FALSE;
     Window focus;
     int rtr;
 
-    LOADETER_FUNC(etersoft_1version);
-    if ( etersoft_1version && (etersoft_1version() == 8) ) b1c8 = TRUE;
-
     if (!(hwnd = GetAncestor( hwnd, GA_ROOT ))) return;
     if (!(data = X11DRV_get_win_data( hwnd ))) return;
-    if ((data->managed || !data->whole_window) && !b1c8) return;
 
     XGetInputFocus( display, &focus, &rtr );
     if (!data->managed && get_handle(focus)) return;
@@ -2279,7 +2272,7 @@ void CDECL X11DRV_SetFocus( HWND hwnd )
     XConfigureWindow( display, data->whole_window, CWStackMode, &changes );
     if (root_window == DefaultRootWindow(display))
     {
-        if (data->managed && data->whole_window && b1c8)
+        if (data->managed && data->whole_window)
             raise_window( hwnd, display );
 
         /* we must not use CurrentTime (ICCCM), so try to use last message time instead */
-- 
1.6.1.3.GIT

